package com.benyun.core.controller;

import com.benyun.core.entity.bo.BrandGeoLabelBo;
import com.benyun.core.entity.bo.BrandSearch;
import com.benyun.core.entity.vo.ListQueryBody;
import com.benyun.core.service.BrandService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.R;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/brand")
public class BrandController extends BaseController {
    @Autowired
    private BrandService brandService;

//    获取品牌信息列表
    @GetMapping("/search")
    public R search(String text){
        List<BrandSearch> list = brandService.searchByLikeName(text);
        return R.ok(list);
    }

//    获取品牌信息列表
    @PostMapping("/list")
    public R list(ListQueryBody body){
        String userId = "1";
        return R.ok(brandService.searchListByMulti(body,userId));
    }

//    获取品牌详细信息
    @GetMapping("/info")
    public R info(String brandId){
        return R.ok(brandService.searchByBrandId(brandId));
    }

//    获取品牌物业信息
    @GetMapping("/property")
    public R property(String brandId){
        return R.ok(brandService.searchPropertyByBrandId(brandId));
    }

//    获取品牌城市分布词云
    @GetMapping("/distribution")
    public R distribution(String brandId){
        return R.ok(brandService.searchDisCloudByBrandId(brandId));
    }

//    获取相似品牌
    @GetMapping("/similar")
    public R similar(String brandId){
        return R.ok(brandService.searchSimilarByBrandId(brandId));
    }

//    获取品牌网点营业状态分布
    @GetMapping("/status")
    public R statusDistribution(String brandId){
        return R.ok(brandService.searchStatusByBrandId(brandId));
    }

//    获取品牌网点地图信息
    @GetMapping("/area")
    public R area(String brandId){
        return R.ok(brandService.searchProvinceByBrandId(brandId));
    }

//    获取品牌网点数量及其城市数量分布
    @GetMapping("/shopCount")
    public R shopCount(String brandId){
        return R.ok(brandService.searchDistributionByBrandId(brandId));
    }

//    品牌网点数量对比
    @GetMapping("/total")
    public R total(Integer pageSize){
        return R.ok(brandService.searchTotal(pageSize));
    }

//    获取品牌均分分布
//    已废弃
//    @GetMapping("/average")
//    public R average(String brandId){
//        return R.ok(brandService.searchAvgScoreByBrandId(brandId));
//    }

//    获取各地区品牌网点数量分布情况
//    已废弃
//    @PostMapping("/countDistribution")
//    public R categoryDis(ListQueryBody body){
//        List<String> addrCode = body.getAddrCode();
//        return R.ok(brandService.searchAddrDistribution(addrCode));
//    }

//    获取品牌地理位置标签分布
    @GetMapping("/geolabel")
    public R geolabel(String brandId){
        List<BrandGeoLabelBo> brandGeoLabelBos = brandService.searchGeoLabel(brandId);
        return R.ok(brandGeoLabelBos);
    }

//    行业连锁品牌发展情况
    @PostMapping("/develop")
    public R develop(ListQueryBody body){
        List<String> addrCode = body.getAddrCode();
        List<String> typeCode = body.getTypeCode(); // 网点分类（犇云）预留
        List<String> brandId = body.getBrandId();
        return null;
    }

//    连锁品牌近期开关店情况
    @GetMapping("/opclose")
    public R opclose(ListQueryBody body){
        List<String> industryCode = body.getIndustryCode(); // 预留
        String startTime = body.getStartTime();
        String endTime = body.getEndTime();
        return null;
    }
}
